@@ -2,14 +2,10 @@ from abc import ABC
 from .base_period import AbstractPeriod
 
 
-class AbstractDateTimePeriod(AbstractPeriod, ABC):
-    """ A period that contains a date and a time """
-
-
-class WallClockDateTimePeriod(AbstractDateTimePeriod, ABC):
+class AbstractWallClockPeriod(AbstractPeriod, ABC):
     """ A datetime period whose duration corresponds to the clock on the wall even if there's a DST change """
 
 
-class AbsoluteDateTimePeriod(AbstractDateTimePeriod, ABC):
+class AbstractAbsolutePeriod(AbstractPeriod, ABC):
     """ A datetime period whose duration accounts for any clock changes (shift forward/back) and updates its duration
-    to reflect that change """
\ No newline at end of file
+    to reflect that change """
